<?php

namespace Assetdocs\Stock\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Stock\Interfaces\StockRepositoryInterface;
use Assetdocs\Stock\Repositories\Presenter\StockItemTransformer;

/**
 * Pubic API controller class.
 */
class StockApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Stock\Interfaces\StockRepositoryInterface $stock
     *
     * @return type
     */
    public function __construct(StockRepositoryInterface $stock)
    {
        $this->middleware('api');

        $this->repository = $stock;
        parent::__construct();
    }

    /**
     * Show stock's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $stocks = $this->repository
            ->pushCriteria(new \Assetdocs\Stock\Repositories\Criteria\StockPublicCriteria())
            ->setPresenter('\\Assetdocs\\Stock\\Repositories\\Presenter\\StockListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $stocks['code'] = 2000;
        return response()->json($stocks)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show stock.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $stock = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($stock)) {
            $stock         = $this->itemPresenter($module, new StockItemTransformer);
            $stock['code'] = 2001;
            return response()->json($stock)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
