<?php

namespace Assetdocs\Stock\Policies;

use App\User;
use Illuminate\Auth\Access\HandlesAuthorization;
use Assetdocs\Stock\Models\Stock;

class StockPolicy
{
    use HandlesAuthorization;

    /**
     * Determine if the given user can view the stock.
     *
     * @param User $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function view(User $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.view') && $user->is('admin')) {
            return true;
        }

        return $user->id === $stock->user_id;
    }

    /**
     * Determine if the given user can create a stock.
     *
     * @param User $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function create(User $user)
    {
        return  $user->canDo('stock.stock.create');
    }

    /**
     * Determine if the given user can update the given stock.
     *
     * @param User $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function update(User $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.update') && $user->is('admin')) {
            return true;
        }

        return $user->id === $stock->user_id;
    }

    /**
     * Determine if the given user can delete the given stock.
     *
     * @param User $user
     * @param Stock $stock
     *
     * @return bool
     */
    public function destroy(User $user, Stock $stock)
    {
        if ($user->canDo('stock.stock.delete') && $user->is('admin')) {
            return true;
        }

        return $user->id === $stock->user_id;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperUser()) {
            return true;
        }
    }
}
